@@ -496,3 +496,22 @@ setMethod("lambdamax.diag", "codaMCMC", function(x, ...)
     lambdamax.diag(as(x, "MCMClist"), ...))
 setMethod("lambdamax.diag", "dcmle", function(x, ...)
     lambdamax.diag(as(x, "MCMClist"), ...))
+
+setGeneric("HPDinterval", function(x, ...)
+    standardGeneric("HPDinterval"))
+setMethod("HPDinterval", "MCMClist", function(x, ...)
+    coda::HPDinterval(x, ...))
+setMethod("HPDinterval", "codaMCMC", function(x, ...)
+    HPDinterval(as(x, "MCMClist"), ...))
+setMethod("HPDinterval", "dcmle", function(x, ...)
+    HPDinterval(as(x, "MCMClist"), ...))
+
+setGeneric("rejectionRate", function(x, ...)
+    standardGeneric("rejectionRate"))
+setMethod("rejectionRate", "MCMClist", function(x, ...)
+    coda::rejectionRate(x, ...))
+setMethod("rejectionRate", "codaMCMC", function(x, ...)
+    rejectionRate(as(x, "MCMClist"), ...))
+setMethod("rejectionRate", "dcmle", function(x, ...)
+    rejectionRate(as(x, "MCMClist"), ...))
+
